|pypi| |travis| |black| |dependabot|

Python Cafeteria Package
========================

A convenience package providing various building blocks for pythonic patterns.


.. |pypi| image:: https://badge.fury.io/py/cafeteria.svg
    :target: https://badge.fury.io/py/cafeteria
.. |travis| image:: https://travis-ci.org/abn/cafeteria.svg?branch=master
    :target: https://travis-ci.org/abn/cafeteria
.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/ambv/black
.. |dependabot| image:: https://api.dependabot.com/badges/status?host=github&repo=abn/cafeteria
    :target: https://dependabot.com
